Py4JNetworkException (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j

## Class Py4JNetworkException

- java.lang.Object
- - java.lang.Throwable
  - - java.lang.Exception
    - - java.lang.RuntimeException
      - - py4j.Py4JException
        - - py4j.Py4JNetworkException

- All Implemented Interfaces:
    java.io.Serializable

      public class Py4JNetworkException
      extends Py4JException

  Exception raised when a network error is encountered while using Py4J.

  See Also:
    Serialized Form

- - ### Nested Class Summary

    Nested Classes
    Modifier and Type | Class and Description
    --- | ---
    `static class` | `Py4JNetworkException.ErrorTime`

  - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JNetworkException()`
    `Py4JNetworkException(Py4JNetworkException.ErrorTime when)`
    `Py4JNetworkException(java.lang.String message)`
    `Py4JNetworkException(java.lang.String message, Py4JNetworkException.ErrorTime when)`
    `Py4JNetworkException(java.lang.String message, java.lang.Throwable cause)`
    `Py4JNetworkException(java.lang.String message, java.lang.Throwable cause, Py4JNetworkException.ErrorTime when)`
    `Py4JNetworkException(java.lang.Throwable cause)`

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `Py4JNetworkException.ErrorTime` | `getWhen()`

    - ### Methods inherited from class java.lang.Throwable

      `addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JNetworkException

          public Py4JNetworkException()

    - #### Py4JNetworkException

          public Py4JNetworkException(Py4JNetworkException.ErrorTime when)

    - #### Py4JNetworkException

          public Py4JNetworkException(java.lang.String message)

    - #### Py4JNetworkException

          public Py4JNetworkException(java.lang.String message,
                                      Py4JNetworkException.ErrorTime when)

    - #### Py4JNetworkException

          public Py4JNetworkException(java.lang.String message,
                                      java.lang.Throwable cause)

    - #### Py4JNetworkException

          public Py4JNetworkException(java.lang.String message,
                                      java.lang.Throwable cause,
                                      Py4JNetworkException.ErrorTime when)

    - #### Py4JNetworkException

          public Py4JNetworkException(java.lang.Throwable cause)

  - ### Method Detail

    - #### getWhen

          public Py4JNetworkException.ErrorTime getWhen()